package WebGUI::i18n::German::Asset;
use utf8;
our $I18N = {
  '%s is not a valid depth' => {
    'lastUpdated' => '1224797605',
    'message' => '%s ist keine gültige Tiefe'
  },
  104 => {
    'lastUpdated' => '1149227599',
    'message' => 'URL'
  },
  '104 description' => {
    'lastUpdated' => '1170451499',
    'message' => '<p>Die eindeutige URL dieses Asset. Wenn Sie das Feld leer lassen, dann wird die URL automatisch aus der übergeordneten URL und dem <strong>Menutitel</strong> gebildet.</p>'
  },
  105 => {
    'lastUpdated' => '1153126726',
    'message' => 'Anzeige'
  },
  107 => {
    'lastUpdated' => '1153126733',
    'message' => 'Sicherheit'
  },
  1073 => {
    'lastUpdated' => '1153126742',
    'message' => 'Style Template'
  },
  1079 => {
    'lastUpdated' => '1153126758',
    'message' => 'Style Druckversion'
  },
  108 => {
    'lastUpdated' => '1153680962',
    'message' => 'Eigentümer'
  },
  '108 description' => {
    'lastUpdated' => '1170451700',
    'message' => '<p>Wer ein Asset erstellt hat, ist in der Regel dessen Eigentümer. Dieser Benutzer hat alle Rechte zum Editieren und Betrachten des Assets.</p><p><strong>Hinweis:</strong> Der Eigent&uuml;mer kann durch einen Administrator geändert werden.</p>'
  },
  1082 => {
    'lastUpdated' => '1153126771',
    'message' => 'Zwischenablage'
  },
  1083 => {
    'lastUpdated' => '1153126777',
    'message' => 'Neuer Inhalt'
  },
  11 => {
    'lastUpdated' => '1153126936',
    'message' => 'Mülleimer leeren.'
  },
  174 => {
    'lastUpdated' => '1153126792',
    'message' => 'Titel anzeigen?'
  },
  411 => {
    'lastUpdated' => '1170451647',
    'message' => 'Menütitel'
  },
  '411 description' => {
    'lastUpdated' => '1170451743',
    'message' => '<p>Ein kurzer Titel, der in der Navigation erscheinen soll. Wenn Sie ihn leer lassen, wird hier der <strong>Titel</strong> eingefügt.</p>'
  },
  412 => {
    'lastUpdated' => '1153126903',
    'message' => 'Zusammenfassung'
  },
  '412 description' => {
    'lastUpdated' => '1170451766',
    'message' => '<p>Eine Kurzbeschreibung dieses Assets.</p>'
  },
  43 => {
    'lastUpdated' => '1250929849',
    'message' => 'Sind Sie sicher, dass Sie diesen Inhalt löschen möchten? Achtung: Dieser Vorgang unterliegt nicht der Versionierung und wird unverzüglich durchgeführt!  '
  },
  486 => {
    'lastUpdated' => '1153126990',
    'message' => 'Datentyp'
  },
  487 => {
    'lastUpdated' => '1170451857',
    'message' => 'Mögliche Werte'
  },
  85 => {
    'lastUpdated' => '1153127008',
    'message' => 'Beschreibung'
  },
  871 => {
    'lastUpdated' => '1153127020',
    'message' => 'Wer darf bearbeiten?'
  },
  '871 description' => {
    'lastUpdated' => '1170452259',
    'message' => '<p>Wählen Sie die Gruppe aus, die dieses Asset bearbeiten darf. Die Gruppe, die die Berechtigung zum Bearbeiten hat, kann das Asset auch sehen. <br /></p>'
  },
  872 => {
    'lastUpdated' => '1170451365',
    'message' => 'Wer kann das Asset sehen?'
  },
  '872 description' => {
    'lastUpdated' => '1170452378',
    'message' => '<p>Wählen sie die Gruppe, die dieses Asset sehen darf. Sollen Besucher <strong>und</strong> registrierte Nutzer das Asset sehen können, w&auml;hlen Sie die Gruppe &quot;Everybody&quot; aus.</p>'
  },
  886 => {
    'lastUpdated' => '1170452411',
    'message' => 'Von der Navigation verbergen? '
  },
  '886 description' => {
    'lastUpdated' => '1170452445',
    'message' => 'Wählen Sie hier aus, ob das Asset in der Navigation und Sitemap angezeigt werden soll oder nicht. '
  },
  895 => {
    'lastUpdated' => '1170452523',
    'message' => 'Cache Timeout'
  },
  896 => {
    'lastUpdated' => '1153127343',
    'message' => 'Cache Timeout für Besucher'
  },
  940 => {
    'lastUpdated' => '1170451385',
    'message' => 'In neuem Fenster öffnen?'
  },
  '940 description' => {
    'lastUpdated' => '1153127552',
    'message' => '<p>Wählen Sie &quot;Ja&quot;, um dieses Asset in einem neuen Browserfenster zu öffnen.</p><p>Achtung: Dies kann unter Umst&auml;nden zu diversen Problemen führen. Insbesondere kann es bei einigen Navigationstypen zu Fehler f&uuml;hren, ebenso wenn der Benutzer JavaScript ausgeschaltet hat oder beim Einsatz von Pop-Up-Blockern.</p>'
  },
  949 => {
    'lastUpdated' => '1170452686',
    'message' => 'Zwischenablage verwalten.'
  },
  950 => {
    'lastUpdated' => '1170452675',
    'message' => 'Zwischenablage leeren.'
  },
  951 => {
    'lastUpdated' => '1170452722',
    'message' => 'Sind Sie sicher, dass Sie den Inhalt der Zwischenablage in den Mülleimer verschieben möchten?'
  },
  954 => {
    'lastUpdated' => '1170452734',
    'message' => 'System-Zwischenablage verwalten.'
  },
  959 => {
    'lastUpdated' => '1153127709',
    'message' => 'System-Zwischenablage löschen.'
  },
  964 => {
    'lastUpdated' => '1170452763',
    'message' => 'System-Mülleimer verwalten.'
  },
  965 => {
    'lastUpdated' => '1153127746',
    'message' => 'System-Mülleimer'
  },
  966 => {
    'lastUpdated' => '1153127760',
    'message' => 'System-Zwischenablage'
  },
  99 => {
    'lastUpdated' => '1153127771',
    'message' => 'Titel'
  },
  '99 description' => {
    'lastUpdated' => '1178788228',
    'message' => '<p>Der Title dieses Assets. Er sollte den Inhalt beschreiben, aber nicht sehr lang sein. Wird er leer gelassen, wird als Standard &quot;Untitled&quot; eingefügt.</p><p><em>Hinweis:</em> Geben Sie <strong>immer</strong> einen Titel an, selbst wenn Sie ihn im Asset-Template nicht nutzen. An mehreren Stellen, wie z.B. dem Seitenbaum, der Zwischenablage und dem M&uuml;lleimer unterscheiden sich Assets nur anhand ihres Titels.</p>'
  },
  'Add new field' => {
    'lastUpdated' => '1170452938',
    'message' => 'Neuen Metadaten-Eintrag hinzufügen.'
  },
  'Add new field description' => {
    'lastUpdated' => '1170453034',
    'message' => '<p>Öffnet ein Formular zum Hinzufügen neuer Metadaten-Felder zu diesem Asset.</p>'
  },
  'Allowed Classes' => {
    'lastUpdated' => '1298376204',
    'message' => 'Erlaubte Klassen'
  },
  'Allowed Classes hoverHelp' => {
    'lastUpdated' => '1298376225',
    'message' => 'Welche Assets nutzen diese Metadaten?'
  },
  'Any Class' => {
    'lastUpdated' => '1259144684',
    'message' => 'Jede Klasse'
  },
  'Attempting to commit changes' => {
    'lastUpdated' => '1258546853',
    'message' => 'Änderungen werden durchgeführt...'
  },
  'Class Icon' => {
    'lastUpdated' => '1170453489',
    'message' => 'Kategoriensymbol'
  },
  'Class Icon help' => {
    'lastUpdated' => '1170453597',
    'message' => '<p>Bei jedem Asset wird auch ein Kategoriensymbol angezigt. Die meisten Kategoriensymbole sind eindeutig einem Asset zugeordnet und sind kleinere Versionen der Symbole, die in der Admin-Konsole im Menü Neuer Inhalt angezeigt werden. Beim Klick auf das Kategoriensymbol erscheint ein Men&uuml; mit erweiterten Editierfunktionen.</p>'
  },
  'Clearing asset tables' => {
    'lastUpdated' => '1246486657',
    'message' => 'Bereinigung der Assettabellen'
  },
  'Clearing cache' => {
    'lastUpdated' => '1246486681',
    'message' => 'Löschen des Cache'
  },
  'Clearing search index' => {
    'lastUpdated' => '1246486714',
    'message' => 'Bereinigung Suchindex'
  },
  'Copy' => {
    'lastUpdated' => '1223575321',
    'message' => 'Kopieren'
  },
  'Copy Assets' => {
    'lastUpdated' => '1274268117',
    'message' => 'Kopiere Assets'
  },
  'Data Type description' => {
    'lastUpdated' => '1170453634',
    'message' => '<p>Wählen Sie die Art des Formularelements für dieses Feld aus.</p>'
  },
  'Delete Assets' => {
    'lastUpdated' => '1251893507',
    'message' => 'Assets löschen'
  },
  'Delete Metadata field' => {
    'lastUpdated' => '1170453667',
    'message' => 'Metadaten Eigenschaft löschen'
  },
  'Deleting exported files' => {
    'lastUpdated' => '1246486748',
    'message' => 'Löschen der exportierten Dateien'
  },
  'Deleting keywords' => {
    'lastUpdated' => '1246486774',
    'message' => 'Löschen Schlagwörter'
  },
  'Depth' => {
    'lastUpdated' => '1153128502',
    'message' => 'Tiefe'
  },
  'Depth description' => {
    'lastUpdated' => '1170453740',
    'message' => '<p>Definiert die Tiefe, bis zu welcher der Seitenbaum exportiert werden soll. Bei einem Wert von 0 wird nur die aktuelle Seite exportiert.</p>'
  },
  'Edit Metadata' => {
    'lastUpdated' => '1170453761',
    'message' => 'Metadaten Eigenschaft editieren'
  },
  'Error getting asset with assetId %s' => {
    'lastUpdated' => '1246486814',
    'message' => 'Fehler beim Aufruf des Assets mit Id %s'
  },
  'Error: Cannot instantiate template' => {
    'lastUpdated' => '1223575484',
    'message' => 'Fehler: Template nicht instantiiert'
  },
  'Export Page' => {
    'lastUpdated' => '1170453772',
    'message' => 'Seite exportieren'
  },
  'Export Related Assets' => {
    'lastUpdated' => '1301988571',
    'message' => 'Zugehörige Assets exportieren'
  },
  'Export Related Assets description' => {
    'lastUpdated' => '1301988553',
    'message' => 'Zugehörige Assets in den Export mit aufnehmen?'
  },
  'Export as user' => {
    'lastUpdated' => '1170453781',
    'message' => 'Exportieren als Benutzer'
  },
  'Export as user description' => {
    'lastUpdated' => '1170453810',
    'message' => '<p>Führt einen Seitenexport unter dieser Benutzerkennung durch. Standard ist &quot;Besucher&quot;.</p>'
  },
  'Export site root URL' => {
    'lastUpdated' => '1223575619',
    'message' => 'Export URL höchster Ebene'
  },
  'Export site root URL description' => {
    'lastUpdated' => '1227565822',
    'message' => 'Eine URL für die Weitergabe an Macro Widgets'
  },
  'Extras URL' => {
    'lastUpdated' => '1170453822',
    'message' => 'Extras URL'
  },
  'Extras URL description' => {
    'lastUpdated' => '1170453858',
    'message' => '<p>Definiert den Extras URL. Standard ist der Wert für extrasURL aus der WebGUI Konfigurationsdatei.</p>'
  },
  'Field Id' => {
    'lastUpdated' => '1170453868',
    'message' => 'Feld ID'
  },
  'Field Name description' => {
    'lastUpdated' => '1215472175',
    'message' => '<p>Der Name dieser Metadaten Eigenschaft muss eindeutig sein.<br />Es wird empfohlen, nur Buchstaben (a-z), Zahlen (0-9) oder Unterstriche (_) für die Feldnamen zu verwenden.</p>'
  },
  'Field name' => {
    'lastUpdated' => '1170453943',
    'message' => 'Feldname'
  },
  'Metadata' => {
    'lastUpdated' => '1153201484',
    'message' => 'Metadaten'
  },
  'Metadata Description description' => {
    'lastUpdated' => '1170453986',
    'message' => '<p>Eine optional Beschreibung für diese Metadaten Eigenschaft. Dieser Text wird als Mouseover-Text im Asset-Eigenschaften Karteireiter angezeigt.</p>'
  },
  'More' => {
    'lastUpdated' => '1227565835',
    'message' => 'Mehr'
  },
  'Page Export' => {
    'lastUpdated' => '1170453999',
    'message' => 'Seite, Exportieren'
  },
  'Page Export Status' => {
    'lastUpdated' => '1170454010',
    'message' => 'Seiten Export Status'
  },
  'Paste' => {
    'lastUpdated' => '1251229370',
    'message' => 'Einfügen'
  },
  'Paste Assets' => {
    'lastUpdated' => '1251229391',
    'message' => 'Assets einfügen'
  },
  'Possible Values description' => {
    'lastUpdated' => '1244362568',
    'message' => 'Dieses Feld wird nur für die Datentypen &quot;Radio List&quot; und &quot;Select List&quot; genutzt. Geben Sie die Werte zeilenweise ein, die erscheinen sollen. Jede Zeile sollte weniger als 255 Zeichen lang sein.'
  },
  'Processing form data' => {
    'lastUpdated' => '1258546889',
    'message' => 'Formulardaten werden verarbeitet...'
  },
  'Purging %s' => {
    'lastUpdated' => '1246486368',
    'message' => 'Löschen %s'
  },
  'Purging shortcuts' => {
    'lastUpdated' => '1246486454',
    'message' => 'Verknüpfungen zum Löschen '
  },
  'Select' => {
    'lastUpdated' => '1153238197',
    'message' => 'Auswählen...'
  },
  'Set Rank' => {
    'lastUpdated' => '1245620457',
    'message' => 'Reihenfolge einstellen'
  },
  'Trying to delete system page %s.  Aborting' => {
    'lastUpdated' => '1251893528',
    'message' => 'Der Versuch, die Systemseite %s zu löschen, wurde abgebrochen.'
  },
  'Undefined child' => {
    'lastUpdated' => '1246486591',
    'message' => 'Versuch zum Löschen der Systemseite %s. Der Löschvorgang wurde abgebrochen.'
  },
  'Uploads URL' => {
    'lastUpdated' => '1170454199',
    'message' => 'Uploads URL'
  },
  'Uploads URL description' => {
    'lastUpdated' => '1170454219',
    'message' => '<p>Definiert den Uploads URL. Vorgabe ist der konfigurierte Wert für uploadsURL aus der WebGUI Konfigurationsdatei.</p>'
  },
  'You cannot edit the asset %s, skipping' => {
    'lastUpdated' => '1246486542',
    'message' => 'Sie können das Asset %s nicht bearbeiten.'
  },
  'add the missing page' => {
    'lastUpdated' => '1170454236',
    'message' => 'Die fehlende Seite hinzufügen.'
  },
  'ago' => {
    'lastUpdated' => '1153238539',
    'message' => 'früher'
  },
  'apply' => {
    'lastUpdated' => '1236433662',
    'message' => 'Übernehmen'
  },
  'asset' => {
    'lastUpdated' => '1153238556',
    'message' => 'Asset'
  },
  'asset id' => {
    'lastUpdated' => '1170454286',
    'message' => 'Asset ID'
  },
  'asset id description' => {
    'lastUpdated' => '1170454315',
    'message' => '<p>Dies ist der eindeutige Bezeichner von WebGUI für dieses Asset. Normale Benutzer werden diese Asset ID nie benötigen, fortgeschrittene Anwender k&ouml;nnen sie z.B. bei eigenen SQL-Reports einsetzen. Die Asset ID kann nicht geändert werden.</p>'
  },
  'asset list title' => {
    'lastUpdated' => '1170454376',
    'message' => 'Liste der verfügbaren Assets'
  },
  'asset template asset var title' => {
    'lastUpdated' => '1170454433',
    'message' => 'Asset Template Asset Variablen'
  },
  'asset template title' => {
    'lastUpdated' => '1170454468',
    'message' => 'Asset Template Variablen'
  },
  'assetHistory' => {
    'lastUpdated' => '1238017406',
    'message' => 'Historie zum Asset'
  },
  'assetId' => {
    'lastUpdated' => '1257324282',
    'message' => 'Der eindeutige Bezeichner dieses Asstes, base64-kodiert'
  },
  'assetIdHex' => {
    'lastUpdated' => '1257324311',
    'message' => 'Der eindeutige Bezeichner dieses Asstes, hexadezimal kodiert.'
  },
  'assetSize' => {
    'lastUpdated' => '1170454592',
    'message' => 'Größe dieses Assets in Bytes. Summe aus allen Datenbankfeldern und Anhängen.'
  },
  'assets' => {
    'lastUpdated' => '1170454599',
    'message' => 'Assets'
  },
  'bad user privileges' => {
    'lastUpdated' => '1170454618',
    'message' => 'Der Benutzer hat keine Berechtigung, diese Seite zu betrachten.'
  },
  'change' => {
    'lastUpdated' => '1170454642',
    'message' => 'Rekursiv ändern?'
  },
  'change url' => {
    'lastUpdated' => '1153242622',
    'message' => 'URL ändern'
  },
  'change url help' => {
    'lastUpdated' => '1170454842',
    'message' => 'Zeigt die &quot;URL ändern&quot; Seite für dieses Asset an.'
  },
  'clear package flag' => {
    'lastUpdated' => '1275484798',
    'message' => 'Paket-Marker entfernen'
  },
  'committed versions' => {
    'lastUpdated' => '1170454956',
    'message' => 'Festgelegte Versionen'
  },
  'confirm change' => {
    'lastUpdated' => '1153243168',
    'message' => 'Sind Sie sicher?'
  },
  'confirm change url message' => {
    'lastUpdated' => '1170455023',
    'message' => 'Setzen Sie diesen Wert auf &quot;Ja&quot;, um zu bestätigen, dass Sie diesen URL dauerhaft &auml;ndern möchten. Auf diese Weise l&ouml;schen Sie alle alten Versionen dieses Assets.'
  },
  'content profiling' => {
    'lastUpdated' => '1153243725',
    'message' => 'Inhalt profilieren'
  },
  'controls' => {
    'lastUpdated' => '1170455252',
    'message' => 'Dies sind die Symbole und URLs für das Editieren, Ausschneiden, Kopieren, Löschen und Neuanordnen des Assets.'
  },
  'copy' => {
    'lastUpdated' => '1223575356',
    'message' => 'kopieren'
  },
  'could not create' => {
    'lastUpdated' => '1168956497',
    'message' => '%s konnte nicht erzeugt werden: %s'
  },
  'could not create path' => {
    'lastUpdated' => '1170455322',
    'message' => '%-s konnte wegen %-s nich angelegt werden.<br />
Dies bedeutet in der Regel, dass Sie eine Seite anlegen möchtgen, die den selben Namen wie der Ordner hat.'
  },
  'could not open path' => {
    'lastUpdated' => '1153244067',
    'message' => '%-s konnte wegen %-s nicht angelegt werden.'
  },
  'could not rmdir' => {
    'lastUpdated' => '1170455352',
    'message' => 'Verzeichnis %s konnte nicht gelöscht werden: %s'
  },
  'could not symlink' => {
    'lastUpdated' => '1168956612',
    'message' => 'Symlink von %s nach %s konnte nicht erzeugt werden: %s'
  },
  'could not unlink' => {
    'lastUpdated' => '1170455376',
    'message' => '%s konnte nicht gelöscht werden: %s'
  },
  'create package' => {
    'lastUpdated' => '1170455393',
    'message' => 'Als Paket zur Verfügung stellen?'
  },
  'create shortcut' => {
    'lastUpdated' => '1170455406',
    'message' => 'Verknüpfung erstellen'
  },
  'current url' => {
    'lastUpdated' => '1153244249',
    'message' => 'Aktueller URL'
  },
  'cut' => {
    'lastUpdated' => '1153244261',
    'message' => 'Ausschneiden'
  },
  'default value' => {
    'lastUpdated' => '1192785177',
    'message' => 'Voreinstellung'
  },
  'default value description' => {
    'lastUpdated' => '1217253936',
    'message' => 'Standardwert für dieses Feld. Falls es mehrere Standardwerte gibt, z.B. bei einer Check Box Liste, dann Eingabe ein Wert pro Zeile. Limitiert auf insgesamt 255 Zeichen.'
  },
  'delete' => {
    'lastUpdated' => '1170455432',
    'message' => 'Löschen'
  },
  'deleteConfirm' => {
    'lastUpdated' => '1170455449',
    'message' => 'Diese Metadaten Eigenschaft wirklich löschen?'
  },
  'demote' => {
    'lastUpdated' => '1153244443',
    'message' => 'Nach unten verschieben'
  },
  'demote %s' => {
    'lastUpdated' => '1245620484',
    'message' => '%s nach unten verschieben'
  },
  'demote help' => {
    'lastUpdated' => '1153244426',
    'message' => 'Dieses Asset auf der Seite um eine Position nach unten verschieben.'
  },
  'directory index' => {
    'lastUpdated' => '1153244460',
    'message' => 'Verzeichnisindex'
  },
  'directory index description' => {
    'lastUpdated' => '1170455501',
    'message' => '<p>Wenn der URL des Assets, das exportiert werden soll, ein Verzeichnis darstellt, wird der Verzeichnisindex angehängt.</p>'
  },
  'does asset inherit URL from parent' => {
    'lastUpdated' => '1217253965',
    'message' => 'Eltern URL voranstellen?'
  },
  'does asset inherit URL from parent description' => {
    'lastUpdated' => '1217253998',
    'message' => 'Soll der URL dieses Assets die URL des Elternassets vorangestellt werden?'
  },
  'done' => {
    'lastUpdated' => '1153244542',
    'message' => 'Fertig'
  },
  'duplicate' => {
    'lastUpdated' => '1153244554',
    'message' => 'Duplizieren'
  },
  'duplicateField' => {
    'lastUpdated' => '1170455532',
    'message' => '<p><strong>Fehler: Feldname &quot;%field%&quot; wird bereits benutzt.</strong></p>'
  },
  'edit' => {
    'lastUpdated' => '1153244582',
    'message' => 'Editieren'
  },
  'edit branch' => {
    'lastUpdated' => '1170455549',
    'message' => 'Zweig bearbeiten'
  },
  'edit branch help' => {
    'lastUpdated' => '1170455697',
    'message' => 'Die &quot;Zweig bearbeiten&quot; Maske anzeigen, um Änderungen an diesem Asset und allen Assets unterhalb durchzuführen.'
  },
  'edit branch url help' => {
    'lastUpdated' => '1170456717',
    'message' => '<p>Sie können den URL auf zwei Arten ändern. Über den Basis URL (links Feld) oder über den Datei URL (rechtes Feld). F&uuml;r den Basis URL gibt es drei Optionen:</p> <dl> <dt>Elternteil URL</dt> <dd>Dieser URL beginnt mit dem URL des Elternteils.</dd> <dt>Spezifizierte Basis<br /> </dt> <dd>Enter in a new base URL via the field that appears when Specified Base is selected.</dd> <dt>Nichts</dt> <dd>Allen Assets einen &quot;top-level&quot; haben lassen.</dd> </dl> <p>Es gibt auch drei Optionen f&uuml;r den Datei URL:</p> <dl> <dt>Men&uuml; Titel</dt> <dd>Der neue URL basiert auf dem Men&uuml; Titel Feld des Assets.</dd> <dt>Titel</dt> <dd>Der neue URL basiert auf dem Titel Feld des Assets.</dd> <dt>Aktueller URL</dt> <dd>Der neue URL basiert auf dem vorhandenen URL des Assets.</dd> </dl>'
  },
  'editing %s' => {
    'lastUpdated' => '1245620503',
    'message' => '%s bearbeiten'
  },
  'encrypt page' => {
    'lastUpdated' => '1170457382',
    'message' => 'Inhalt verschlüsseln?'
  },
  'encrypt page description' => {
    'lastUpdated' => '1170457440',
    'message' => '<p>Soll die Seite, die dieses Asset enthält, über eine SSL-Verbindung &uuml;bertragen werden?</p>'
  },
  'encryptPage' => {
    'lastUpdated' => '1170457535',
    'message' => 'Boolscher Wert, der wahr ist, wenn die Seite via SSL verschlüsselt &uuml;bertragen werden soll.'
  },
  'errorEmptyField' => {
    'lastUpdated' => '1170457562',
    'message' => '<p><strong>Fehler: Feldname darf nicht leer sein.</strong></p>'
  },
  'export' => {
    'lastUpdated' => '1221215524',
    'message' => 'Export'
  },
  'export information' => {
    'lastUpdated' => '1170457581',
    'message' => '<p>%d Seiten in %d Sekunden exportiert.</p>'
  },
  'exporting page' => {
    'lastUpdated' => '1153261911',
    'message' => 'Seite %-s wird exportiert......'
  },
  'extra head tags' => {
    'lastUpdated' => '1170457602',
    'message' => 'Zusätzliche &lt;head&gt;-Elemente (tags)'
  },
  'extra head tags description' => {
    'lastUpdated' => '1170457628',
    'message' => '<p>Diese Tags werden im &lt;head&gt;-Bereich jeder Seite ergänzt, auf der dieses Asset erscheint.</p>'
  },
  'extraHeadTags' => {
    'lastUpdated' => '1168849557',
    'message' => 'Zusätzliche Tags, die dem Header der Seite hinzugefügt wird, die das Asset enth&auml;lt. Diese werden standardm&auml;ssig hinzugef&uuml;gt, so dass Sie sie nicht extra hinzuf&uuml;gen m&uuml;ssen, ausser Sie wollen, dass sie zweimal vorhanden sind. '
  },
  'extrasUploads form hoverHelp' => {
    'lastUpdated' => '1170458540',
    'message' => 'Welche Aktionen sollen bezüglich extras und uploads Verzeichnis, die oftmals von Teilen der Seite referenziert werden, ausgef&uuml;hrt werden. Symlink bedeutet, dass ein symbolischer Link (nicht verf&uuml;gbar auf allen Systemen) auf das originale Verzeichnis benutzt wird. None bedeutet nichts tun, d.h. extras und uploads Verzeichnis werden ignoriert; sehr warscheinlich werden Referenzen darauf nicht mehr funktionieren ausser Sie haben die Verzeichnisse vorher schon vorbereitet.'
  },
  'extrasUploads form label' => {
    'lastUpdated' => '1170458600',
    'message' => 'Extras und uploads Verzeichnisse'
  },
  'extrasUploads form option none' => {
    'lastUpdated' => '1170458615',
    'message' => 'Nichts'
  },
  'extrasUploads form option symlink' => {
    'lastUpdated' => '1170458623',
    'message' => 'Symlink'
  },
  'extrasUploads symlinking' => {
    'lastUpdated' => '1170458554',
    'message' => 'Symlinking extras und uploads Verzeichnis.'
  },
  'groupIdEdit' => {
    'lastUpdated' => '1168850456',
    'message' => 'Die ID der Gruppe, die das Asset editieren darf.'
  },
  'groupIdView' => {
    'lastUpdated' => '1170457657',
    'message' => 'Die ID der Gruppe, die das Asset betrachten darf.'
  },
  'import' => {
    'lastUpdated' => '1153262773',
    'message' => 'Import'
  },
  'indexing %s' => {
    'lastUpdated' => '1245620532',
    'message' => '%s indizieren'
  },
  'inherit parent permissions' => {
    'lastUpdated' => '1223575415',
    'message' => 'Eltern-Rechte übernehmen'
  },
  'is not a valid userId' => {
    'lastUpdated' => '1224797637',
    'message' => 'is keine gültige Benutzer-ID'
  },
  'isHidden' => {
    'lastUpdated' => '1170458448',
    'message' => 'Boolscher Wert, der wahr ist, wenn das Asset in der Navigation nicht angezeigt wird.'
  },
  'isPackage' => {
    'lastUpdated' => '1170458463',
    'message' => 'Boolscher Wert, der wahr ist, wenn das Asset ein Paket ist.'
  },
  'isPrototype' => {
    'lastUpdated' => '1170458637',
    'message' => 'Boolscher Wert, der wahr ist, wenn das Asset ein Prototy ist.'
  },
  'keywords' => {
    'lastUpdated' => '1262767073',
    'message' => 'Schlüsselworte'
  },
  'keywords help' => {
    'lastUpdated' => '1262767184',
    'message' => 'Schlüsselworte werden automatisch dem Metatag \'keywords\' in diesem Asset und dem WebGUI Suchindex hinzugefügt. Mehrere Schlüsselworte werden durch Komma getrennt.'
  },
  'keywords template var' => {
    'lastUpdated' => '1241153991',
    'message' => 'Eine Info mit den Schlagwörtern für dieses Asset. Einzelne Schlagwörter werden mit Leerstellen verbunden. Wenn ein Schlagwort Leerstellen enthält, wird es mit Anführungszeichen versehen.'
  },
  'last updated' => {
    'lastUpdated' => '1153262812',
    'message' => 'Zuletzt aktualisiert'
  },
  'lock' => {
    'lastUpdated' => '1153262959',
    'message' => 'Sperren'
  },
  'lock help' => {
    'lastUpdated' => '1170458679',
    'message' => 'Sichern Sie sich eine Kopie dieses Assets zur Bearbeitung. Dies sperrt das Asset für jeden, der nicht unter der aktuellen Versionsmarkierung arbeitet. Diese Option wird nur angezeigt, wenn das Asset nicht bereits gesperrt ist.'
  },
  'locked' => {
    'lastUpdated' => '1153262993',
    'message' => 'Gesperrt'
  },
  'locked by' => {
    'lastUpdated' => '1234734865',
    'message' => 'Gesperrt von'
  },
  'make asset exportable' => {
    'lastUpdated' => '1201601501',
    'message' => 'Asset exportierbar?'
  },
  'make asset exportable description' => {
    'lastUpdated' => '1217434685',
    'message' => '<p>Darf dieses Asset als statisches HTML exportiert werden? Dieses Asset und alle seine Vorgänger müssen exportierbar sein, damit dieses Asset exportiert werden kann. Ausserdem muss das Exportieren in der WebGUI Konfigurationsdatei aktiviert sein.</p><p>&nbsp;</p><p>&nbsp;</p><p>&nbsp;</p>'
  },
  'make package' => {
    'lastUpdated' => '1170458694',
    'message' => 'Paket erzeugen?'
  },
  'make package description' => {
    'lastUpdated' => '1168963847',
    'message' => '<p>Viele WebGUI Aufgaben wiederholen sich regelmäßig. Durch das Erstellen eines Pakets automatisieren Sie Aufgaben, wie das Erstellen eines Assets oder Mengen davon. Vorkonfigurierte Assets können danach überall auf der Site wiederverwendet werden. Wenn Sie diese Asset als Paket verf&uuml;gbar machen wollen, w&auml;hlen Sie &quot;Ja&quot; aus.'
  },
  'make prototype' => {
    'lastUpdated' => '1170458719',
    'message' => 'Prototyp erstellen?'
  },
  'make prototype description' => {
    'lastUpdated' => '1154467385',
    'message' => '<p>Dieses Asset als Inhalts-Prototyp definieren, so dass es auf Ihrer Site von anderen eingesetzt werden kann.</p>'
  },
  'manage' => {
    'lastUpdated' => '1153261587',
    'message' => 'Verwalten'
  },
  'manage help' => {
    'lastUpdated' => '1170458775',
    'message' => 'Ruft den Asset Manager auf und zeigt das aktuelle Asset und evtl. Kinder an.'
  },
  'menu label' => {
    'lastUpdated' => '1217254165',
    'message' => 'Mehr'
  },
  'menuTitle' => {
    'lastUpdated' => '1170458788',
    'message' => 'Der Titel des Assets, der in der Navigation angezeigt wird.'
  },
  'metadata edit property' => {
    'lastUpdated' => '1168851230',
    'message' => 'Metadaten bearbeiten'
  },
  'missing page query' => {
    'lastUpdated' => '1170458876',
    'message' => 'Die Seite, die Sie aufgerufen haben, exisitert nicht. Was möchten Sie tun?'
  },
  'moving %s' => {
    'lastUpdated' => '1245620802',
    'message' => '%s neu benennen'
  },
  'moving %s aside' => {
    'lastUpdated' => '1245620846',
    'message' => '%s zurückstellen'
  },
  'moving %s back' => {
    'lastUpdated' => '1245620761',
    'message' => '%s zurück'
  },
  'need a depth' => {
    'lastUpdated' => '1224797669',
    'message' => 'Angabe einer Tiefe ist erforderlich'
  },
  'need a userId parameter' => {
    'lastUpdated' => '1224797691',
    'message' => 'eine Benutzer-ID ist erforderlich'
  },
  'newWindow' => {
    'lastUpdated' => '1170458894',
    'message' => 'Boolscher Wert, der wahr ist, wenn das Asset in einem neuen Browser Fenster geöffnet wird.'
  },
  'no results' => {
    'lastUpdated' => '1215170551',
    'message' => 'Kein Ergebniss'
  },
  'none' => {
    'lastUpdated' => '1153262099',
    'message' => 'Nichts'
  },
  'over max assets' => {
    'lastUpdated' => '1170458914',
    'message' => 'Der Administrator hat die Anzahl der zulässigen Assets dieser Site begrenzt und Sie haben das Limit überschritten. Löschen Sie einige alte Assets, um wieder neue hinzuf&uuml;gen zu k&ouml;nnen.'
  },
  'ownerUserId' => {
    'lastUpdated' => '1170458568',
    'message' => 'Die ID des Benutzers, der das Asset besitzt.'
  },
  'package corrupt' => {
    'lastUpdated' => '1170458491',
    'message' => 'Das Paket das Sie importieren wollten enthält Fehler. Es wurde bis zum Auftreten des Fehlers importiert. Um dies rückg&auml;nig zu machen, kehren Sie zur letzten Versionierungsmarkierung zur&uuml;ck.'
  },
  'package extract error' => {
    'lastUpdated' => '1206969119',
    'message' => 'Fehler beim auspacken des Pakets'
  },
  'packages' => {
    'lastUpdated' => '1153263288',
    'message' => 'Pakete'
  },
  'page indicator' => {
    'lastUpdated' => '1217254183',
    'message' => 'Zeige Seite %s von %s'
  },
  'parent url' => {
    'lastUpdated' => '1170458428',
    'message' => 'Elternteil URL'
  },
  'pasting %s' => {
    'lastUpdated' => '1251229411',
    'message' => '%s einfügen'
  },
  'promote' => {
    'lastUpdated' => '1170458411',
    'message' => 'Fördern'
  },
  'promote %s' => {
    'lastUpdated' => '1245620722',
    'message' => '% nach unten'
  },
  'promote help' => {
    'lastUpdated' => '1170457638',
    'message' => 'Dieses Asset auf der Seite um eine Position nach oben verschieben.'
  },
  'properties' => {
    'lastUpdated' => '1153263330',
    'message' => 'Eigenschaften'
  },
  'prototype using title' => {
    'lastUpdated' => '1153263257',
    'message' => 'Inhalts-Prototypen, Verwendung'
  },
  'purge' => {
    'lastUpdated' => '1154466874',
    'message' => 'Leeren'
  },
  'purge old asset revisions' => {
    'lastUpdated' => '1170457719',
    'message' => 'Alte Asset Revisionen löschen'
  },
  'purge old trash' => {
    'lastUpdated' => '1170457685',
    'message' => 'Alten Abfall entfernen'
  },
  'purge revision after' => {
    'lastUpdated' => '1170457483',
    'message' => 'Alte Version aufräumen nach'
  },
  'purge revision after help' => {
    'lastUpdated' => '1170457373',
    'message' => 'Wie lange sollen alte Versionen eines Asset aufgehoben werden? Alte Versionen sind Versionen, die vom Nutzer nicht mehr gesehen werden aber im Versionierungssystem für ein Rollback nach wie vor vorhanden sind.'
  },
  'purge revision prompt' => {
    'lastUpdated' => '1170457353',
    'message' => 'Sind Sie sicher, dass Sie diese Version von diesem Asset löschen m&ouml;chten? Nach dem L&ouml;schen kann sie NICHT wieder hergestellt werden!'
  },
  'purge trash after' => {
    'lastUpdated' => '1170457321',
    'message' => 'Mülleimer leeren nach'
  },
  'purge trash after help' => {
    'lastUpdated' => '1227565882',
    'message' => 'Wie lange soll ein Asset im Mülleimer bleiben, bis es entfernt wird? Beachten Sie: wenn es entfernt wird, werden ebenso alle Versionen und Nachfahren entfernt.'
  },
  'rank' => {
    'lastUpdated' => '1153262742',
    'message' => 'Rang'
  },
  'restore' => {
    'lastUpdated' => '1153262080',
    'message' => 'Wiederherstellen'
  },
  'revised by' => {
    'lastUpdated' => '1153262068',
    'message' => 'Versioniert von'
  },
  'revision date' => {
    'lastUpdated' => '1153262046',
    'message' => 'Versionsdatum'
  },
  'revisions' => {
    'lastUpdated' => '1153262004',
    'message' => 'Versionen'
  },
  'revisions help' => {
    'lastUpdated' => '1153262034',
    'message' => 'Eine Liste aller Versionen dieses Assets anzeigen.<br />'
  },
  'rootUrl default not present' => {
    'lastUpdated' => '1170457242',
    'message' => 'Nicht Symlinking Standart Asset; nicht in exportierten Unterbäumen enthalten.<br /> '
  },
  'rootUrl form hoverHelp' => {
    'lastUpdated' => '1170457162',
    'message' => 'Welche Tätigkeit, zum betreffend Fragen zum Wurzel URL zu nehmen. Symlink Rückstellung bedeutet, eine symbolische Verbindung von der Akte des Index root URL zur Index Datei des Standard Wertes herzustellen (nicht auf allen Systemen vorhanden). Keines bedeutet, nichts zu tun, das normalerweise Fragen zum root URL veranlaßt, im exportierten Aufstellungsort zur&uuml;ckgewiesen zu werden.'
  },
  'rootUrl form label' => {
    'lastUpdated' => '1168963969',
    'message' => 'Root URL'
  },
  'rootUrl form option none' => {
    'lastUpdated' => '1170451292',
    'message' => 'Nichts'
  },
  'rootUrl form option symlinkDefault' => {
    'lastUpdated' => '1170451334',
    'message' => 'Symlink Standardwert.'
  },
  'rootUrl symlinking default' => {
    'lastUpdated' => '1168848184',
    'message' => 'Symlinking extras und uploads Verzeichnis.'
  },
  'save and commit' => {
    'lastUpdated' => '1170456962',
    'message' => 'Speichern und Übertragen (Commit)'
  },
  'search' => {
    'lastUpdated' => '1215170569',
    'message' => 'Suche'
  },
  'select all' => {
    'lastUpdated' => '1153261991',
    'message' => 'Alles auswählen'
  },
  'size' => {
    'lastUpdated' => '1153261973',
    'message' => 'Größe'
  },
  'skipping %s' => {
    'lastUpdated' => '1245620589',
    'message' => '%s übergehen'
  },
  'specified base' => {
    'lastUpdated' => '1170456876',
    'message' => 'Angegebene Basis'
  },
  'status' => {
    'lastUpdated' => '1170456862',
    'message' => 'Status des Assets bezüglich der Versionskontrolle. Typischerweise ist dies &quot;approved&quot;, &quot;pending&quot; oder &quot;committed&quot;.'
  },
  'swap first' => {
    'lastUpdated' => '1245620659',
    'message' => 'Erste/r austauschen'
  },
  'swap second' => {
    'lastUpdated' => '1245620678',
    'message' => 'Zweite/r austauschen'
  },
  'synopsis' => {
    'lastUpdated' => '1170456848',
    'message' => 'Kurze Beschreibung des Inhalts des Assets.'
  },
  'tag name' => {
    'lastUpdated' => '1153263007',
    'message' => 'Tagname'
  },
  'this asset only' => {
    'lastUpdated' => '1192798167',
    'message' => 'Nur dieser Asset'
  },
  'title' => {
    'lastUpdated' => '1170456818',
    'message' => 'Titel des Assets'
  },
  'topicName' => {
    'lastUpdated' => '1153261956',
    'message' => 'Assets'
  },
  'type' => {
    'lastUpdated' => '1153261940',
    'message' => 'Typ'
  },
  'unlocked' => {
    'lastUpdated' => '1234737050',
    'message' => 'entsperrt'
  },
  'update' => {
    'lastUpdated' => '1217146900',
    'message' => 'Aktualisieren'
  },
  'url' => {
    'lastUpdated' => '1168847957',
    'message' => 'URL des Assets.'
  },
  'usePackedHeadTags description' => {
    'lastUpdated' => '1241154103',
    'message' => 'Für schnellere Downloads werden komprimierte Head-Tags verwendet.'
  },
  'usePackedHeadTags label' => {
    'lastUpdated' => '1241154122',
    'message' => 'Komprimierte Head-Tags verwenden'
  },
  'view' => {
    'lastUpdated' => '1153261929',
    'message' => 'Betrachten'
  },
  'view help' => {
    'lastUpdated' => '1170456757',
    'message' => 'Die meisten Asstes sind Teil eines Container-Assets, z.B. einer Seite oder einem Ordner. Diese Option ermöglicht es, das Asset alleine zu betrachten.'
  },
  'with children' => {
    'lastUpdated' => '1192798281',
    'message' => 'Mit Kindern'
  },
  'with descendants' => {
    'lastUpdated' => '1192798267',
    'message' => 'Mit Nachkommen'
  },
  'with selected' => {
    'lastUpdated' => '1221215481',
    'message' => 'Mit der Auswahl'
  }
}
;

1;
